@@ -20,6 +20,12 @@ answer1 = json.loads(arxiv_download(paper_id="2506.15003"))["title"]
 print("Answer 1:", answer1, end="")
 """
 
+SNIPPET_4 = """
+doc = arxiv_download(paper_id="2506.15003")
+answer = document_qa(question="What is the capital of France?", document=doc)
+print(answer, end="")
+"""
+
 PIP_INSTALL_SNIPPET = """
 import subprocess
 proc = subprocess.run(['pip', 'install', 'transformers'], capture_output=True)
@@ -31,24 +37,24 @@ print(proc.stderr)
 class TestPythonExecutor:
     async def test_python_executor_basic(self) -> None:
         python_executor = PythonExecutor()
-        result1 = await python_executor.invoke(SNIPPET_1)
-        result2 = await python_executor.invoke(SNIPPET_2)
+        result1 = await python_executor.ainvoke(SNIPPET_1)
+        result2 = await python_executor.ainvoke(SNIPPET_2)
         assert result1.stdout == "Answer 1"
         assert result2.stdout == "Variable still here: Answer 1"
 
     async def test_python_executor_pip_install(self) -> None:
         python_executor = PythonExecutor()
-        result = await python_executor.invoke(PIP_INSTALL_SNIPPET)
+        result = await python_executor.ainvoke(PIP_INSTALL_SNIPPET)
         assert "ERROR" in result.stdout, result.stdout
 
     async def test_python_executor_result_expr(self) -> None:
         python_executor = PythonExecutor()
-        result = await python_executor.invoke("r = 4\nr")
+        result = await python_executor.ainvoke("r = 4\nr")
         assert result.result == 4
 
     async def test_python_executor_result_dict(self) -> None:
         python_executor = PythonExecutor()
-        result = await python_executor.invoke("r = {'a': 4}\nr")
+        result = await python_executor.ainvoke("r = {'a': 4}\nr")
         assert result.result == {"a": 4}
 
     async def test_python_executor_mcp_call_no_tools(self, mcp_server_test: MCPServerTest) -> None:
@@ -57,7 +63,7 @@ class TestPythonExecutor:
             tools_server_host=mcp_server_test.host,
             tools_server_port=mcp_server_test.port,
         )
-        result = await python_executor.invoke(SNIPPET_3)
+        result = await python_executor.ainvoke(SNIPPET_3)
         assert (
             result.stdout
             != "Answer 1: Effect of surface magnetism on the x-ray spectra of hollow atoms"
@@ -75,7 +81,7 @@ class TestPythonExecutor:
             tools_server_host=mcp_server_test.host,
             tools_server_port=mcp_server_test.port,
         )
-        result = await executor.invoke(SNIPPET_3)
+        result = await executor.ainvoke(SNIPPET_3)
         assert (
             result.stdout
             == "Answer 1: Effect of surface magnetism on the x-ray spectra of hollow atoms"
@@ -84,7 +90,20 @@ class TestPythonExecutor:
     async def test_python_executor_non_existing_tool(self) -> None:
         executor = PythonExecutor(tool_names=["arxiv_download"])
         with pytest.raises(ValueError):
-            await executor.invoke(SNIPPET_3)
+            await executor.ainvoke(SNIPPET_3)
+
+    async def test_python_executor_mcp_document_qa(
+        self,
+        mcp_server_test: MCPServerTest,
+    ) -> None:
+        _ = mcp_server_test
+        executor = PythonExecutor(
+            tool_names=["arxiv_download", "document_qa"],
+            tools_server_host=mcp_server_test.host,
+            tools_server_port=mcp_server_test.port,
+        )
+        result = await executor.ainvoke(SNIPPET_4)
+        assert result.stdout and "Error" not in result.stdout, str(result)
 
 
 def test_execresult_to_message_with_text_result() -> None:
